==> ZenTaoALM.12.4.1.int.zip: zentaoalm/module/score/lang/vi.php <==
<?php
$lang->score->common       = 'Điểm của bạn';
$lang->score->record       = 'Điểm';
$lang->score->current      = 'Điểm của bạn';
$lang->score->level        = 'Mức điểm';
$lang->score->reset        = 'Thiết lập lại';
$lang->score->tips         = 'Điểm được thêm hôm qua: <strong>%d</strong><br/> Tổng điểm: <strong>%d</strong>';
$lang->score->resetTips    = 'Đợi một chút. <strong>Đừng đóng cửa sổ này.</strong>';
$lang->score->resetStart   = 'Bắt đầu';
$lang->score->resetLoading = 'Đang xử lý: ';
$lang->score->resetFinish  = 'Kết thúc';

$lang->score->id      = 'ID';
$lang->score->userID  = 'ID Người dùng';
$lang->score->account = 'Người dùng';
$lang->score->module  = 'Module';
$lang->score->method  = 'Hành động';
$lang->score->before  = 'Trước';
$lang->score->score   = '+/-';
$lang->score->after   = 'Sau';
$lang->score->time    = 'Thời gian';
$lang->score->desc    = 'Mô tả';
$lang->score->noLimit = 'Không có giới hạn';
$lang->score->times   = 'Số lần';
$lang->score->hour    = 'giờ';

$lang->score->modules['task']        = 'Nhiệm vụ';
$lang->score->modules['tutorial']    = 'Hướng dẫn';
$lang->score->modules['user']        = 'Người dùng';
$lang->score->modules['ajax']        = 'Khác';
$lang->score->modules['doc']         = 'Tài liệu';
$lang->score->modules['todo']        = 'Việc làm';
$lang->score->modules['story']       = 'Câu chuyện';
$lang->score->modules['bug']         = 'Bug';
$lang->score->modules['testcase']    = 'Tình huống';
$lang->score->modules['testtask']    = 'Yêu cầu';
$lang->score->modules['build']       = 'Bản dựng';
$lang->score->modules['project']     = 'Dự án';
$lang->score->modules['productplan'] = 'Kế hoạch';
$lang->score->modules['release']     = 'Phát hành';
$lang->score->modules['block']       = 'Block';
$lang->score->modules['search']      = 'Tìm kiếm';

$lang->score->methods['task']['create']              = 'Tạo nhiệm vụ';
$lang->score->methods['task']['close']               = 'Đóng nhiệm vụ';
$lang->score->methods['task']['finish']              = 'Hoàn thành nhiệm vụ';
$lang->score->methods['tutorial']['finish']          = 'Hoàn thành hướng dẫn';
$lang->score->methods['user']['login']               = 'Đăng nhập';
$lang->score->methods['user']['changePassword']      = 'Thay đổi mật khẩu';
$lang->score->methods['user']['editProfile']         = 'Sửa hồ sơ';
$lang->score->methods['ajax']['selectTheme']         = 'Thay đổi Theme';
$lang->score->methods['ajax']['selectLang']          = 'Thay đổi ngôn ngữ';
$lang->score->methods['ajax']['showSearchMenu']      = 'Tìm kiếm nâng cao';
$lang->score->methods['ajax']['customMenu']          = 'Tùy biến Menu';
$lang->score->methods['ajax']['dragSelected']        = 'Kéo vào trang danh sách';
$lang->score->methods['ajax']['lastNext']            = 'Phím tắt chuyển trang';
$lang->score->methods['ajax']['switchToDataTable']   = 'Chuyển bảng dữ liệu';
$lang->score->methods['ajax']['submitPage']          = 'Thay đổi số trang';
$lang->score->methods['ajax']['quickJump']           = 'Chuyển nhanh';
$lang->score->methods['ajax']['batchCreate']         = 'Tạo hàng loạt lần đầu';
$lang->score->methods['ajax']['batchEdit']           = 'Sửa hàng loạt lần đầu';
$lang->score->methods['ajax']['batchOther']          = 'Hành động hàng loạt khác';
$lang->score->methods['doc']['create']               = 'Tạo tài liệu';
$lang->score->methods['todo']['create']              = 'Tạo việc làm';
$lang->score->methods['story']['create']             = 'Tạo câu chuyện';
$lang->score->methods['story']['close']              = 'Đóng câu chuyện';
$lang->score->methods['bug']['create']               = 'Báo cáo Bug';
$lang->score->methods['bug']['confirmBug']           = 'Xác nhận Bug';
$lang->score->methods['bug']['createFormCase']       = 'Báo cáo Bug từ tình huống';
$lang->score->methods['bug']['resolve']              = 'Giải quyết Bug';
$lang->score->methods['bug']['saveTplModal']         = 'Lưu mẫu';
$lang->score->methods['testtask']['runCase']         = 'Chạy tình huống';
$lang->score->methods['testcase']['create']          = 'Tạo tình huống';
$lang->score->methods['build']['create']             = 'Tạo bản dựng';
$lang->score->methods['project']['create']           = "Tạo {$lang->projectCommon}";
$lang->score->methods['project']['close']            = "Hoàn thành {$lang->projectCommon}";
$lang->score->methods['productplan']['create']       = 'Tạo kế hoạch';
$lang->score->methods['release']['create']           = 'Tạo phát hành';
$lang->score->methods['block']['set']                = 'Tùy biến Block';
$lang->score->methods['search']['saveQuery']         = 'Lưu truy vấn';
$lang->score->methods['search']['saveQueryAdvanced'] = 'Tìm kiếm nâng cao';

$lang->score->extended['user']['changePassword'] = 'Nhận ##strength,1## điểm, nếu độ mạnh mật khẩu trung bình. Nhận ##strength,2## điểm, nếu mật khẩu mạnh.';
$lang->score->extended['project']['close']       = 'Sau khi dự án đóng, quản lý dự án nhận điểm ##manager,close## và thành viên đội nhóm nhận điểm ##member,close## . Nếu nó được hoàn thành đúng giờ hoặc sớm hơn, quản lý dự án này nhận điểm ##manager,onTime## và thành viên đội nhóm nhận điểm  ##member,onTime##.';
$lang->score->extended['bug']['resolve']         = 'Sau khi một bug được giải quyết, nhận thêm điểm theo mức độ nghiêm trọng của nó. S1, + ##severity,1##; S2 + ##severity,2##, S3 + ##severity,3##.';
$lang->score->extended['bug']['confirmBug']      = 'Sau khi một bug được xác nhận, nhận thêm điểm theo mức độ nghiêm trọng của nó. S1, + ##severity,1##; S2 + ##severity,2##, S3 + ##severity,3##.';
$lang->score->extended['task']['finish']         = 'Sau khi một nhiệm vụ được hoàn thành, nhận điểm mở rộng theo vòng (giờ công / 10  Dự tính / đã làm) + điểm ưu tiên (p1 ##pri,1##, p2 ##pri,2##).';
$lang->score->extended['story']['close']         = 'Sau khi một câu chuyện được đóng, người tạo sẽ nhận thêm ##createID## points.';

==> ZenTaoALM.15.0.rc2.int.zip: zentaoalm/module/score/lang/vi.php <==
<?php
$lang->score->common       = 'Điểm của bạn';
$lang->score->record       = 'Điểm';
$lang->score->current      = 'Điểm của bạn';
$lang->score->level        = 'Mức điểm';
$lang->score->reset        = 'Thiết lập lại';
$lang->score->tips         = 'Điểm được thêm hôm qua: <strong>%d</strong><br/> Tổng điểm: <strong>%d</strong>';
$lang->score->resetTips    = 'Đợi một chút. <strong>Đừng đóng cửa sổ này.</strong>';
$lang->score->resetStart   = 'Bắt đầu';
$lang->score->resetLoading = 'Đang xử lý: ';
$lang->score->resetFinish  = 'Kết thúc';

$lang->score->id      = 'ID';
$lang->score->userID  = 'ID Người dùng';
$lang->score->account = 'Người dùng';
$lang->score->module  = 'Module';
$lang->score->method  = 'Hành động';
$lang->score->before  = 'Trước';
$lang->score->score   = '+/-';
$lang->score->after   = 'Sau';
$lang->score->time    = 'Thời gian';
$lang->score->desc    = 'Mô tả';
$lang->score->noLimit = 'Không có giới hạn';
$lang->score->times   = 'Số lần';
$lang->score->hour    = 'giờ';

$lang->score->modules['task']        = 'Nhiệm vụ';
$lang->score->modules['tutorial']    = 'Hướng dẫn';
$lang->score->modules['user']        = 'Người dùng';
$lang->score->modules['ajax']        = 'Khác';
$lang->score->modules['doc']         = 'Tài liệu';
$lang->score->modules['todo']        = 'Việc làm';
$lang->score->modules['story']       = 'Câu chuyện';
$lang->score->modules['bug']         = 'Bug';
$lang->score->modules['testcase']    = 'Tình huống';
$lang->score->modules['testtask']    = 'Yêu cầu';
$lang->score->modules['build']       = 'Bản dựng';
$lang->score->modules['execution']   = $lang->executionCommon;
$lang->score->modules['productplan'] = 'Kế hoạch';
$lang->score->modules['release']     = 'Phát hành';
$lang->score->modules['block']       = 'Block';
$lang->score->modules['search']      = 'Tìm kiếm';

$lang->score->methods['task']['create']              = 'Tạo nhiệm vụ';
$lang->score->methods['task']['close']               = 'Đóng nhiệm vụ';
$lang->score->methods['task']['finish']              = 'Hoàn thành nhiệm vụ';
$lang->score->methods['tutorial']['finish']          = 'Hoàn thành hướng dẫn';
$lang->score->methods['user']['login']               = 'Đăng nhập';
$lang->score->methods['user']['changePassword']      = 'Thay đổi mật khẩu';
$lang->score->methods['user']['editProfile']         = 'Sửa hồ sơ';
$lang->score->methods['ajax']['selectTheme']         = 'Thay đổi Theme';
$lang->score->methods['ajax']['selectLang']          = 'Thay đổi ngôn ngữ';
$lang->score->methods['ajax']['showSearchMenu']      = 'Tìm kiếm nâng cao';
$lang->score->methods['ajax']['customMenu']          = 'Tùy biến Menu';
$lang->score->methods['ajax']['dragSelected']        = 'Kéo vào trang danh sách';
$lang->score->methods['ajax']['lastNext']            = 'Phím tắt chuyển trang';
$lang->score->methods['ajax']['switchToDataTable']   = 'Chuyển bảng dữ liệu';
$lang->score->methods['ajax']['submitPage']          = 'Thay đổi số trang';
$lang->score->methods['ajax']['quickJump']           = 'Chuyển nhanh';
$lang->score->methods['ajax']['batchCreate']         = 'Tạo hàng loạt lần đầu';
$lang->score->methods['ajax']['batchEdit']           = 'Sửa hàng loạt lần đầu';
$lang->score->methods['ajax']['batchOther']          = 'Hành động hàng loạt khác';
$lang->score->methods['doc']['create']               = 'Tạo tài liệu';
$lang->score->methods['todo']['create']              = 'Tạo việc làm';
$lang->score->methods['story']['create']             = 'Tạo câu chuyện';
$lang->score->methods['story']['close']              = 'Đóng câu chuyện';
$lang->score->methods['bug']['create']               = 'Báo cáo Bug';
$lang->score->methods['bug']['confirmBug']           = 'Xác nhận Bug';
$lang->score->methods['bug']['createFormCase']       = 'Báo cáo Bug từ tình huống';
$lang->score->methods['bug']['resolve']              = 'Giải quyết Bug';
$lang->score->methods['bug']['saveTplModal']         = 'Lưu mẫu';
$lang->score->methods['testtask']['runCase']         = 'Chạy tình huống';
$lang->score->methods['testcase']['create']          = 'Tạo tình huống';
$lang->score->methods['build']['create']             = 'Tạo bản dựng';
$lang->score->methods['execution']['create']         = "Tạo {$lang->executionCommon}";
$lang->score->methods['execution']['close']          = "Hoàn thành {$lang->executionCommon}";
$lang->score->methods['productplan']['create']       = 'Tạo kế hoạch';
$lang->score->methods['release']['create']           = 'Tạo phát hành';
$lang->score->methods['block']['set']                = 'Tùy biến Block';
$lang->score->methods['search']['saveQuery']         = 'Lưu truy vấn';
$lang->score->methods['search']['saveQueryAdvanced'] = 'Tìm kiếm nâng cao';

$lang->score->extended['user']['changePassword'] = 'Nhận ##strength,1## điểm, nếu độ mạnh mật khẩu trung bình. Nhận ##strength,2## điểm, nếu mật khẩu mạnh.';
$lang->score->extended['execution']['close']     = 'Sau khi dự án đóng, quản lý dự án nhận điểm ##manager,close## và thành viên đội nhóm nhận điểm ##member,close## . Nếu nó được hoàn thành đúng giờ hoặc sớm hơn, quản lý dự án này nhận điểm ##manager,onTime## và thành viên đội nhóm nhận điểm  ##member,onTime##.';
$lang->score->extended['bug']['resolve']         = 'Sau khi một bug được giải quyết, nhận thêm điểm theo mức độ nghiêm trọng của nó. S1, + ##severity,1##; S2 + ##severity,2##, S3 + ##severity,3##.';
$lang->score->extended['bug']['confirmBug']      = 'Sau khi một bug được xác nhận, nhận thêm điểm theo mức độ nghiêm trọng của nó. S1, + ##severity,1##; S2 + ##severity,2##, S3 + ##severity,3##.';
$lang->score->extended['task']['finish']         = 'Sau khi một nhiệm vụ được hoàn thành, nhận điểm mở rộng theo vòng (giờ công / 10  Dự tính / đã làm) + điểm ưu tiên (p1 ##pri,1##, p2 ##pri,2##).';
$lang->score->extended['story']['close']         = 'Sau khi một câu chuyện được đóng, người tạo sẽ nhận thêm ##createID## points.';
